@@ -19,33 +19,38 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <stdio.h>
-#include <glib.h>
-#include <string.h>
-
 #include "gui.h"
 #include "prefs.h"
 #include "i18n.h"
 
-
-int main(int argc, char **argv)
+int main (int argc, char **argv)
 {
+
+GUI *appGUI = NULL;
+
+    appGUI = g_new0 (GUI, 1);
+    g_return_val_if_fail (appGUI != NULL, -1);
+
+    /* default values */
+    appGUI->groups_list_store = NULL;
+    appGUI->uim_widget = NULL;
+
     prefs_read_config ();
 
     gtk_init (&argc, &argv);
 
-#if ENABLE_NLS
     gtk_set_locale();
-    bindtextdomain(PACKAGE, LOCALEDIR);
-    textdomain(PACKAGE);
-#endif
+    bindtextdomain (PACKAGE, LOCALEDIR);
+    textdomain (PACKAGE);
 
-    gui_create_window ();
+    gui_create_window (appGUI);
 
     gtk_main ();
 
     prefs_write_config ();
 
+    g_free (appGUI);
+
     return 0;
 }
 
