@@ -22,12 +22,12 @@
 #ifndef _PREFS_H
 #define _PREFS_H
 
-#include <gtk/gtk.h>
-
-#define CONFIG_DIRNAME      ".clay"
-#define CONFIG_FILENAME     "lss.xml"
+#define CONFIG_FILENAME     ".lss.xml"
 #define CONFIG_NAME         "lss_config"
 
+#define SYMBOL_NAME_LEN     128
+#define BUFFER_SIZE         256
+
 struct lss_prefs
 {
     gint        window_x;
@@ -40,6 +40,7 @@ struct lss_prefs
     gint        enable_ams_symbols;
     gint        send_to_gvim;
     gint        send_to_clipboard;
+    gchar       latest_symbol_name[SYMBOL_NAME_LEN];
 };
 
 extern  struct lss_prefs        config;
