@@ -23,17 +23,12 @@
 #ifndef _SEND_H
 #define _SEND_H
 
-#include <gtk/gtk.h>
-
-#define BUFFER_SIZE                 256
-
 #define GVIM_SERVERS_LIST_CMD       "gvim --serverlist"
 #define GVIM_SERVER_SEND_TEXT_CMD   "gvim --servername %s --remote-send \\%s"
 
+void        drag_and_drop_init          (GtkWidget *widget, GUI *appGUI);
+gboolean    send_symbol_to_gvim         (gchar *symbol);
+gboolean    send_symbol_to_clipboard    (gchar *symbol);
 
-gboolean send_symbol_to_gvim        (gchar *symbol);
-gboolean send_symbol_to_clipboard   (gchar *symbol);
-
-
-#endif /* _PREFS_H */
+#endif /* _SEND_H */
 
